@@ -24,4 +24,4 @@ class AuthenticationUtil(object):
             api_instance = AuthenticationApi(api_client)
 
             authentication = Authentication(strategy=strategy, email=email, password=password, workspaceId=workspace_id)
-            return api_instance.authentication_post(authentication=authentication)
+            return api_instance.post_authentication(authentication=authentication)
